==> safecheck-3.0.72.jar: filiale/qbjyangchun/sqls/FetchPlanUserfiles.sql <==
SELECT
	uf.f_user_id As id, --表档案id
	f_position AS f_weizhi, --安装位置
	gb.f_manufacturers AS f_maker, --气表厂家
	gm.f_meter_style AS f_diaphgram_size, --气表型号
	gb.f_meter_brand AS f_aliasname, --气表品牌
	gb.f_meter_type AS f_meter_type, --气表类型
	f_meter_base AS f_prior_reading, --气表底数
	uf.f_meternumber AS f_meter_no, --表号
	f_aroundmeter AS f_flow_direction, --左右表
	f_metertitles As f_metertitles, --表封号
	f_meter_base As  f_metergasnums, --气表底数
    ui.f_ins_stop_date,--上期保费截止时间
	uf.f_initial_base AS f_initial_base, --表基数
	uf.f_total_fee, --累购金额
	case when uf.f_meter_classify='机表' then uf.f_meter_base else uf.f_total_gas end f_total_gas,--累购气量
	gb.f_collection_type, --购气类型(按金额，按气量)
	f_meter_classify,
    ui.f_last_check_state,
    ui.f_last_checker as f_checker_name,
    ui.f_last_check_date,
    ui.f_last_check_result,
	uf.version,
    case when uf.f_meter_classify='机表' then uf.f_bqf_state else (case when mr.f_valveState = '0' then '开阀' else '关阀' end) end f_valve_state,--开关阀状态
    uf.f_off_valve_reason,--开关阀原因
	uf.f_balance_amount,
    uf.f_defendcard,
    uf.f_defendcard_two,
    ui.f_paper_name,--企业名称(非民用)
    ui.f_idnumber,
    uf.f_balance_gas,
    ui.f_taxpayer_id,--纳税人识别编号(非民用)
    ui.f_contact_user,--联系人(非民用)
    uf.f_userfiles_id,
    sp.f_price_name,
    uf.f_gasproperties, --用气性质
    uf.f_gas_date,   -- 通气时间
    ui.f_gas_pointsnumber,     -- 用气点数量
    uop.f_comments f_zhongdian, --重点用户移入原因
    uop.f_audit_comments --重点用户备注
FROM
	t_userfiles uf
left join t_userinfo ui on	 uf.f_userinfo_id = ui.f_userinfo_id
LEFT JOIN t_user_address u on uf.f_userinfo_id=u.f_userinfo_id
--left join t_userfees tuf on tuf.f_userinfo_id=uf.f_userinfo_id
LEFT JOIN t_gasbrand gb ON uf.f_gasbrand_id = gb.id
LEFT JOIN t_gasmodel gm on uf.f_gasmodel_id = gm.id
left join  t_meteread mr with (nolock) on uf.f_meteread_maxid = mr.id
left join (select * from t_stairprice
   where getdate()>=f_perform_date and getdate()<=f_end_date
 and f_state ='有效')sp on uf.f_price_id=sp.f_price_id
left join (select * from t_userproperties where f_parameter_key = 'blackList' and f_state = '有效') uop on uf.f_userinfo_id = uop.f_userinfo_id
WHERE
	uf.f_userinfo_id = '{f_userid}' and uf.f_table_state in ('正常','停用','待开通')

==> safecheck-3.1.26.jar: filiale/qbjyangchun/sqls/FetchPlanUserfiles.sql <==
SELECT
	uf.f_user_id As id, --表档案id
	f_position AS f_weizhi, --安装位置
	gb.f_manufacturers AS f_maker, --气表厂家
	gm.f_meter_style AS f_diaphgram_size, --气表型号
	gb.f_meter_brand AS f_aliasname, --气表品牌
	gb.f_meter_type AS f_meter_type, --气表类型
	f_meter_base AS f_prior_reading, --气表底数
	uf.f_meternumber AS f_meter_no, --表号
	f_aroundmeter AS f_flow_direction, --左右表
	f_metertitles As f_metertitles, --表封号
	f_meter_base As  f_metergasnums, --气表底数
    ui.f_ins_stop_date,--上期保费截止时间
	uf.f_initial_base AS f_initial_base, --表基数
	uf.f_total_fee, --累购金额
	case when uf.f_meter_classify='机表' then uf.f_meter_base else uf.f_total_gas end f_total_gas,--累购气量
	gb.f_collection_type, --购气类型(按金额，按气量)
	f_meter_classify,
    ui.f_last_check_state,
    ui.f_last_checker as f_checker_name,
    ui.f_last_check_date,
    ui.f_last_check_result,
	uf.version,
    case when uf.f_meter_classify='机表' then uf.f_bqf_state else (case when mr.f_valveState = '0' then '开阀' else '关阀' end) end f_valve_state,--开关阀状态
    uf.f_off_valve_reason,--开关阀原因
	uf.f_balance_amount,
    uf.f_defendcard,
    uf.f_defendcard_two,
    ui.f_paper_name,--企业名称(非民用)
    ui.f_idnumber,
    uf.f_balance_gas,
    ui.f_taxpayer_id,--纳税人识别编号(非民用)
    ui.f_contact_user,--联系人(非民用)
    uf.f_userfiles_id,
    sp.f_price_name,
    uf.f_gasproperties, --用气性质
    uf.f_gas_date,   -- 通气时间
    ui.f_uservent_date,   -- 首次通气时间
    ui.f_gas_pointsnumber,     -- 用气点数量
    uop.f_comments f_zhongdian, --重点用户移入原因
    uop.f_remark f_zhongdian_f_remark, --重点用户移入备注
    uop.f_audit_comments --重点用户申备注
FROM
	t_userfiles uf
left join t_userinfo ui on	 uf.f_userinfo_id = ui.f_userinfo_id
LEFT JOIN t_user_address u on uf.f_userinfo_id=u.f_userinfo_id
--left join t_userfees tuf on tuf.f_userinfo_id=uf.f_userinfo_id
LEFT JOIN t_gasbrand gb ON uf.f_gasbrand_id = gb.id
LEFT JOIN t_gasmodel gm on uf.f_gasmodel_id = gm.id
left join  t_meteread mr with (nolock) on uf.f_meteread_maxid = mr.id
left join (select * from t_stairprice
   where getdate()>=f_perform_date and getdate()<=f_end_date
 and f_state ='有效')sp on uf.f_price_id=sp.f_price_id
left join (select * from t_userproperties where f_parameter_key = 'blackList' and f_state = '有效') uop on uf.f_userinfo_id = uop.f_userinfo_id
WHERE
	uf.f_userinfo_id = '{f_userid}' and uf.f_table_state in ('正常','停用','待开通')
